Adjust clang format to the new versions, revert broken macro layout (#714)

Este commit está contenido en:
Danylo Lytovchenko
2025-08-22 17:23:22 +02:00
cometido por GitHub
padre ed877433f3
commit 2ff2316227
Se han modificado 189 ficheros con 1906 adiciones y 2418 borrados
@@ -32,5 +32,5 @@ __device__ int getSquareOfGlobalFloat() {
extern "C" __global__ void testWeightedCopy(int* a, int* b) {
int tx = threadIdx.x;
b[tx] = deviceGlobalInt1 * a[tx] + deviceGlobalInt2 + static_cast<int>(deviceGlobalShort) +
static_cast<int>(deviceGlobalChar) + getSquareOfGlobalFloat();
static_cast<int>(deviceGlobalChar) + getSquareOfGlobalFloat();
}